Module handle

Module handle 

WorktreeHandle — a live record of a managed git worktree.

Structs

StaleWorktree
A worktree discovered by WorktreeManager::reconcile that is not present in the current process’s own in-memory session state.
WorktreeHandle
A live record of a git worktree that WorktreeManager has created for a subagent.

Constants

BARE_WORKTREE_SENTINEL
Sentinel used for WorktreeHandle::branch_name when a worktree discovered via WorktreeManager::reconcile is the main worktree of a bare repository (git worktree list --porcelain emits a bare line, with no HEAD or branch/detached line at all, for these entries).
DETACHED_BRANCH_SENTINEL
Sentinel used for WorktreeHandle::branch_name when a worktree discovered via WorktreeManager::reconcile is on a detached HEAD rather than a branch (git worktree list --porcelain emits a detached line instead of branch refs/heads/<name> for these entries).